@@ -110,6 +110,7 @@ impl<const L: usize> PartialEq for String<L> {
     }
 }
 
+// == str eq ==
 impl<const L: usize> PartialEq<&str> for String<L> {
     #[inline]
     fn eq(&self, other: &&str) -> bool {
@@ -134,6 +135,31 @@ impl<const L: usize> PartialEq<String<L>> for &str {
     }
 }
 
+// == std String eq ==
+impl<const L: usize> PartialEq<std::string::String> for String<L> {
+    #[inline]
+    fn eq(&self, other: &std::string::String) -> bool {
+        PartialEq::eq(&self[..], &other[..])
+    }
+
+    #[inline]
+    fn ne(&self, other: &std::string::String) -> bool {
+        PartialEq::ne(&self[..], &other[..])
+    }
+}
+
+impl<const L: usize> PartialEq<String<L>> for std::string::String {
+    #[inline]
+    fn eq(&self, other: &String<L>) -> bool {
+        PartialEq::eq(&self[..], &other[..])
+    }
+
+    #[inline]
+    fn ne(&self, other: &String<L>) -> bool {
+        PartialEq::ne(&self[..], &other[..])
+    }
+}
+
 impl<const L: usize> ops::Index<ops::Range<usize>> for String<L> {
     type Output = str;
 
@@ -248,4 +274,15 @@ mod tests {
 
         assert_eq!(&s[..2], "ab");
     }
+
+    #[test]
+    fn eq_impls() {
+        let s_ = "abcde";
+        let s = String::<5>::try_from(s_).unwrap();
+
+        assert_eq!(s_, s);
+
+        let s_ = s_.to_owned();
+        assert_eq!(s_, s);
+    }
 }
